from datetime import date

WEEKDAYS = ["Mo", "Di", "Mi", "Do", "Fr", "Sa", "So"]
MONTHS = [
    "März", "April", "Mai", "Juni", "Juli", "August",
    "September", "Oktober", "November", "Dezember",
    "Januar", "Februar"  # <- Diese Monate gehören zum Ende des KRC-Jahres
]

def is_krc_leap_year(year: int) -> bool:
    """
    KRC-Schaltregel:
    - Alle 4 Jahre ein zusätzlicher Tag
    - Aber NICHT alle 100 Jahre
    - AUSSER alle 400 Jahre wieder doch
    """
    return year % 4 == 0 and (year % 100 != 0 or year % 400 == 0)

def print_krc_calendar(year: int, start_weekday: int = 0):
    """Druckt das KRC-Jahr ab 1. März. start_weekday: 0 = Montag"""
    print(f"Kroesch-Kalenderjahr {year} KRC\n")
    weekday = start_weekday

    for month in MONTHS:
        print(f"\n{month}")
        print(" ".join(WEEKDAYS))
        line = "    " * weekday
        for day in range(1, 31):
            line += f"{day:2d}  "
            weekday = (weekday + 1) % 7
            if weekday == 0:
                print(line)
                line = ""
        if line:
            print(line)

    # Intercalaris
    print("\nIntercalaris (außerhalb der Woche):")
    print("Tag 361")
    if is_krc_leap_year(year):
        print("Tag 362 (Schalttag)")

# Beispiel
print_krc_calendar(12025)
